@@ -73,10 +73,17 @@ from .models.vendor_guardrail import (
     VendorGuardrailInstallResponse,
     VendorGuardrailUninstallResponse,
 )
+from .models.guardrails import (
+    GuardrailAssignmentSetting,
+    GuardrailAssignmentEntity,
+    GuardrailAssignmentRequest,
+    GuardrailAssignmentResponse,
+)
 from .services.vendor_assistant import VendorAssistantService
 from .services.vendor_workflow import VendorWorkflowService
 from .services.vendor_knowledgebase import VendorKnowledgeBaseService
 from .services.vendor_guardrail import VendorGuardrailService
+from .services.codemie_guardrails import CodemieGuardrailService
 
 __version__ = "0.2.12"
 __all__ = [
@@ -132,4 +139,9 @@ __all__ = [
     "VendorGuardrailInstallResponse",
     "VendorGuardrailUninstallResponse",
     "VendorGuardrailService",
+    "GuardrailAssignmentSetting",
+    "GuardrailAssignmentEntity",
+    "GuardrailAssignmentRequest",
+    "GuardrailAssignmentResponse",
+    "CodemieGuardrailService",
 ]
